==> ooo_dev_tools-0.31.0-py3-none-any.whl: ooodev/adapter/table/table_columns_comp.py <==
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from ooodev.adapter.component_base import ComponentBase
from ooodev.adapter.container.enumeration_access_partial import EnumerationAccessPartial
from ooodev.adapter.container.name_access_partial import NameAccessPartial
from ooodev.adapter.container.element_access_partial import ElementAccessPartial
from ooodev.adapter.container.index_access_partial import IndexAccessPartial

if TYPE_CHECKING:
    from com.sun.star.table import TableColumns  # service
    from com.sun.star.table import XTableColumns


class TableColumnsComp(ComponentBase, NameAccessPartial, EnumerationAccessPartial, IndexAccessPartial):
    """
    Class for managing TableColumns Component.

    Provides methods to access columns via index and to insert and remove columns.
    """

    # pylint: disable=unused-argument

    def __init__(self, component: XTableColumns) -> None:
        """
        Constructor

        Args:
            component (XCell): UNO Component that implements ``com.sun.star.table.TableColumns`` service.
        """
        ComponentBase.__init__(self, component)
        ElementAccessPartial.__init__(self, component=self.component)
        NameAccessPartial.__init__(self, component=self.component)
        EnumerationAccessPartial.__init__(self, component=self.component)

    # region Overrides
    def _ComponentBase__get_supported_service_names(self) -> tuple[str, ...]:
        """Returns a tuple of supported service names."""
        return ("com.sun.star.table.TableColumns",)

    # endregion Overrides
    # region XTableColumns
    def insert_by_index(self, index: int, count: int) -> None:
        """
        Inserts a new column at the specified index.

        Args:
            index (int): The index at which the column will be inserted.
            count (int): The number of columns to insert.
        """
        self.component.insertByIndex(index, count)

    def remove_by_index(self, index: int, count: int) -> None:
        """
        Removes columns from the specified index.

        Args:
            index (int): The index at which the column will be removed.
            count (int): The number of columns to remove.
        """
        self.component.removeByIndex(index, count)

    # endregion XTableColumns
    # region Properties
    @property
    def component(self) -> TableColumns:
        """Cell Component"""
        # pylint: disable=no-member
        return cast("TableColumns", self._ComponentBase__get_component())  # type: ignore

    # endregion Properties

==> ooo_dev_tools-0.53.0-py3-none-any.whl: ooodev/adapter/table/table_columns_comp.py <==
from __future__ import annotations
from typing import cast, TYPE_CHECKING

try:
    # python 3.12+
    from typing import override  # noqa # type: ignore
except ImportError:
    from typing_extensions import override  # noqa # type: ignore

from ooodev.adapter.component_base import ComponentBase
from ooodev.adapter.container.enumeration_access_partial import EnumerationAccessPartial
from ooodev.adapter.table.table_columns_partial import TableColumnsPartial

if TYPE_CHECKING:
    from com.sun.star.table import TableColumns  # service
    from com.sun.star.table import XTableColumns


class TableColumnsComp(ComponentBase, TableColumnsPartial, EnumerationAccessPartial):
    """
    Class for managing TableColumns Component.

    Provides methods to access columns via index and to insert and remove columns.
    """

    # this class is very similar to ooodev.adapter.text.table_columns_comp.TableColumnsComp
    # don't get them confused.
    # pylint: disable=unused-argument

    def __init__(self, component: XTableColumns) -> None:
        """
        Constructor

        Args:
            component (XCell): UNO Component that implements ``com.sun.star.table.TableColumns`` service.
        """
        ComponentBase.__init__(self, component)
        TableColumnsPartial.__init__(self, component=component, interface=None)
        # Name access is optional
        # NameAccessPartial.__init__(self, component=self.component)
        EnumerationAccessPartial.__init__(self, component=self.component)

    # region Overrides
    @override
    def _ComponentBase__get_supported_service_names(self) -> tuple[str, ...]:
        """Returns a tuple of supported service names."""
        return ("com.sun.star.table.TableColumns",)

    # endregion Overrides
    # region Properties
    @property
    @override
    def component(self) -> TableColumns:
        """Table columns Component"""
        # pylint: disable=no-member
        return cast("TableColumns", self._ComponentBase__get_component())  # type: ignore

    # endregion Properties
